pub fn map_virtio_error(
error: VirtioError,
operation: &'static str,
) -> DeviceErrorExpand description
Maps a VirtIO error to the runtime category that determines the caller’s recovery action.
pub fn map_virtio_error(
error: VirtioError,
operation: &'static str,
) -> DeviceErrorMaps a VirtIO error to the runtime category that determines the caller’s recovery action.