Module memory

Module memory 

Scoped guest-memory capability used by queue operations. Scoped guest-memory operations used by VirtIO queues.

Structs

AddressSpaceMemory
Adapter for existing address-space accessors used by host tests and standalone device-model users.
DeviceContextMemory
Guest-memory capability adapter for a routed PCI endpoint callback.
NoGuestMemoryAccessor
Placeholder accessor for runtimes that provide guest memory only through a scoped GuestMemory capability at queue-processing time.

Traits

GuestMemory
The minimum guest-memory capability required by a VirtIO queue operation.