#[repr(C)]pub struct VirtqUsedElem {
pub id: u32,
pub len: u32,
}Expand description
VirtIO used ring element structure.
This structure represents the memory layout of a single element in the used ring array according to the VirtIO specification. Each element records information about a completed descriptor chain.
This structure is used by UsedRing to read/write individual used
elements in guest memory through the guest memory accessor.
Fields
id: u32Index of start of used descriptor chain
len: u32Total length of the descriptor chain which was used
Implementations