Scoped guest-memory capability used by queue operations. Scoped guest-memory operations used by VirtIO queues.
Structs
- Address
Space Memory - Adapter for existing address-space accessors used by host tests and standalone device-model users.
- Device
Context Memory - Guest-memory capability adapter for a routed PCI endpoint callback.
- NoGuest
Memory Accessor - Placeholder accessor for runtimes that provide guest memory only through
a scoped
GuestMemorycapability at queue-processing time.
Traits
- Guest
Memory - The minimum guest-memory capability required by a VirtIO queue operation.